# Dashboard #

### Summary
* A set of modules to assist running the CCRenew Performance Engineering Dashboard process.
* The main goal of this package is to reduce time and effort devoted by the
Performance Engineering team for reporting.
* This package replaces the set of one-off scripts that previously used for
the Dashboard process and abstracts away much of the manual entry required
for these files.

### How do I get set up?
* See <a href="./example">User Guide</a>
* Dependencies

### Who do I talk to about errors or feature requests?
* Cypress Creek Renewables Performance Engineering Team